@@ -137,6 +137,8 @@ distributeList(backFit(layer, back.fit, fits, r, k, Z, fit.model))
 }
 ## Create table summarising results - as in "summary" method
 if (!is.null(fix.layers)) layer <- fix.layers + background
+if(verbose)
+{
 if (layer == background) print("No clusters have been found")
 else
 {
@@ -150,7 +152,8 @@ c("Rows", "Cols", "Df", "SS", "MS",
 "Convergence", "Rows Released",
 "Cols Released"))), digits = 15)
 }
-if (layer > background)
+}
+#if (layer > background)
   #new("PlaidResult",
   #list(residuals = drop(Z),fits = lapply(fits[1:layer], drop),
   #layer.df = layer.df[1:layer], rows = r[,1:layer],
@@ -159,9 +162,26 @@ if (layer > background)
   #cols.released = cols.released[1:layer],
   #background = background))
 #  return(BiclustResult(match.call(),r[,1:layer],k[,1:layer],layer-1,last.warning))
-  if(layer<=1)          return(BiclustResult(as.list(match.call()),matrix(NA,1,1),matrix(NA,1,1),0))
-  else if(layer==2)     return(BiclustResult(as.list(match.call()),matrix(r[,2:layer],n,1),t(matrix(k[,2:layer],p,1)),1))
-  else                  return(BiclustResult(as.list(match.call()),r[,2:layer],t(k[,2:layer]),layer-1))
+
+  if(layer<=1)          
+    {
+    #MATCHCALL<-list(as.list(match.call()),SS=0,MS=0)
+    return(BiclustResult(as.list(match.call()),matrix(NA,1,1),matrix(NA,1,1),0,list(SS=0,MS=0)))
+    }
+  else
+    {
+    if(layer==2)
+      {
+      #MATCHCALL<-list(as.list(match.call()),SS=SS[1:2],MS=SS[1:2] / layer.df[1:2])
+      return(BiclustResult(as.list(match.call()),matrix(r[,2:layer],n,1),t(matrix(k[,2:layer],p,1)),1,list(SS=SS[1:2],MS=SS[1:2] / layer.df[1:2])))
+      }
+    else
+      {
+      #MATCHCALL<-list(as.list(match.call()),SS=SS[1:layer],MS=SS[1:layer] / layer.df[1:layer])
+      return(BiclustResult(as.list(match.call()),r[,2:layer],t(k[,2:layer]),layer-1,list(SS=SS[1:layer],MS=SS[1:layer] / layer.df[1:layer])))
+      }
+    }
+
 
 # before conception for ColxNumber
 #  else if(layer==2)     return(BiclustResult(match.call(),matrix(r[,2:layer],n,1),matrix(k[,2:layer],p,1),1))
